# Nika

## 1. Описание пакета
Пакет реализует подключение к источникам данных, логирование, обработку ошибок и отправку результата получателю.

# 2. Nika - Общая структура
- Nika
    - colorprint
    - config
    - consumer
    - error
    - filter
    - logger
    - nika
    - postgres
    - producer
    - response
    - util


## 3. Описание модулей и их компонентов
### 3.1 colorprint
### 3.1 config
### 3.1 consumer
### 3.1 error
### 3.1 filter
### 3.1 logger
### 3.1 nika
### 3.1 postgres
### 3.1 producer
### 3.1 response
### 3.1 util

## 4. Примеры
### 4.1 colorprint
### 4.1 config
### 4.1 consumer
### 4.1 error
### 4.1 filter
### 4.1 logger
### 4.1 nika
### 4.1 postgres
### 4.1 producer
### 4.1 response
### 4.1 util